PaymentOptions class

Payment input options class accessKey - Open money payment gateway subscriptions accessKey. You must provide a correct key based on payment mode paymentToken - Server generated token to intialize payment paymentMode - Mode of payment sandbox or live. Default to sandbox

Constructors

PaymentOptions(String accessKey, String paymentToken, [PaymentMode paymentMode = PaymentMode.sandbox])

Properties

accessKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
paymentMode → PaymentMode
final
paymentToken → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toMap → Map<String, String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited